let numVisibleHexagons = 0;

function removeHexagon(hexagon) {
    hexagon.remove(); // remove the hexagon from the DOM
    numVisibleHexagons--; // decrement the count of visible hexagons
}

function animateHexagons() {
    // Get the current vertical position of the user
    const scrollTop = window.pageYOffset || document.documentElement.scrollTop;

    // Move each hexagon based on its individual scroll speed
    const hexagons = document.querySelectorAll(".parallax-hexagon");
    hexagons.forEach((hexagon) => {
        const hexagonSpeed = hexagon.dataset.speed;
        const hexagonTop = hexagon.getBoundingClientRect().top;
        const hexagonBottom = hexagon.getBoundingClientRect().bottom;

        if (hexagonTop < window.innerHeight && hexagonBottom > 0) {
            // Move the hexagon up or down based on the scroll speed
            hexagon.style.transform = `translateY(${scrollTop * hexagonSpeed * 0.5}px)`;

            // If the hexagon has moved outside of the container, move it to the opposite side
            const containerHeight = document.querySelector(".parallax-container").offsetHeight;
            if (hexagonTop > containerHeight || hexagonBottom < 0) {
                hexagon.style.transform = `translateY(-${scrollTop * hexagonSpeed * 0.5}px)`;
            }
        } else if (hexagonTop >= window.innerHeight) {
            // If the hexagon is above the viewport, move it to the bottom of the container
            hexagon.style.transform = `translateY(-${hexagon.offsetHeight}px)`;
        } else if (hexagonBottom <= 0) {
            // If the hexagon is below the viewport, move it to the top of the container
            const containerHeight = document.querySelector(".parallax-container").offsetHeight;
            hexagon.style.transform = `translateY(${containerHeight}px)`;
        }
    });

    // Add new hexagons to the bottom of the container as hexagons move outside of the top
    const containerTop = document.querySelector(".parallax-container").getBoundingClientRect().top;
    if (containerTop > 0) {
        while (containerTop > -300) {
            createHexagon("bottom");
            containerTop = document.querySelector(".parallax-container").getBoundingClientRect().top;
        }
    }
}


// create initial hexagons
for (let i = 0; i < 10; i++) {
    createHexagon();
}

function createHexagon() {
    // Create a new hexagon element
    const hexagon = document.createElement("div");
    hexagon.classList.add("parallax-hexagon");

    // Set a random size between 100px and 400px
    const size = Math.floor(Math.random() * 301) + 100;
    hexagon.style.width = `${size}px`;
    hexagon.style.height = `${size * .85}px`;

    // Set a random position within the parallax container, taking the scroll position into account
    const parallaxContainer = document.querySelector(".parallax-container");
    const containerWidth = parallaxContainer.offsetWidth;
    const containerHeight = parallaxContainer.offsetHeight;
    const scrollTop = window.pageYOffset || document.documentElement.scrollTop;
    hexagon.style.left = `${Math.random() * (containerWidth - size)}px`;
    hexagon.style.top = `${(Math.random() * (containerHeight - size)) + scrollTop}px`;

    // Set a random color between three shades of blue
    const colorChoices = ["#B3DDEF", "#687f98", "#0f5780"];
    const color = colorChoices[Math.floor(Math.random() * colorChoices.length)];
    hexagon.style.backgroundColor = color;

    // Set a random opacity between 0.2 and 0.8
    const opacity = Math.random() * 0.5 + 0.1;
    hexagon.style.opacity = opacity;

    // Set a random speed between 1x and 2x the scroll speed
    const speed = Math.random() + 1;
    hexagon.dataset.speed = speed;

    // Add the hexagon to the parallax container
    parallaxContainer.appendChild(hexagon);
}

// Create a random number of hexagons between 5 and 10
const numHexagons = Math.floor(Math.random() * 4) + 3;
for (let i = 0; i < numHexagons; i++) {
    createHexagon();
}

// Attach a scroll event listener to the window
window.addEventListener("scroll", () => {
    animateHexagons();
});